import type { ZodSchema } from 'zod';
import type { AstroSettings } from '../@types/astro.js';
import type { AstroIntegrationLogger, Logger } from '../core/logger/core.js';
import { DataStore, type MetaStore, type ScopedDataStore } from './data-store.js';
import type { FSWatcher } from 'vite';
export interface ParseDataOptions {
    /** The ID of the entry. Unique per collection */
    id: string;
    /** The raw, unvalidated data of the entry */
    data: Record<string, unknown>;
    /** An optional file path, where the entry represents a local file. */
    filePath?: string;
}
export interface LoaderContext {
    /** The unique name of the collection */
    collection: string;
    /** A database abstraction to store the actual data */
    store: ScopedDataStore;
    /**  A simple KV store, designed for things like sync tokens */
    meta: MetaStore;
    logger: AstroIntegrationLogger;
    settings: AstroSettings;
    /** Validates and parses the data according to the collection schema */
    parseData<T extends Record<string, unknown> = Record<string, unknown>>(props: ParseDataOptions): T;
    /** When running in dev, this is a filesystem watcher that can be used to trigger updates */
    watcher?: FSWatcher;
}
export interface Loader {
    /** Unique name of the loader, e.g. the npm package name */
    name: string;
    /** Do the actual loading of the data */
    load: (context: LoaderContext) => Promise<void>;
    /** Optionally, define the schema of the data. Will be overridden by user-defined schema */
    schema?: ZodSchema | Promise<ZodSchema> | (() => ZodSchema | Promise<ZodSchema>);
    render?: (entry: any) => any;
}
export interface SyncContentLayerOptions {
    store?: DataStore;
    settings: AstroSettings;
    logger: Logger;
    watcher?: FSWatcher;
}
/**
 * Run the `load()` method of each collection's loader, which will load the data and save it in the data store.
 * The loader itself is responsible for deciding whether this will clear and reload the full collection, or
 * perform an incremental update. After the data is loaded, the data store is written to disk.
 */
export declare function syncContentLayer({ settings, logger: globalLogger, store, watcher, }: SyncContentLayerOptions): Promise<void>;
